@@ -2,9 +2,12 @@ from __future__ import annotations
 
 from argparse import Namespace
 
+import pytest
+
 from virtualenv.activation.activator import Activator
 
 
+@pytest.mark.graalpy
 def test_activator_prompt_cwd(monkeypatch, tmp_path):
     class FakeActivator(Activator):
         def generate(self, creator):
