@@ -14,6 +14,7 @@ from typing import NamedTuple
 
 import pytest
 
+from virtualenv.create.via_global_ref.builtin.cpython.common import is_macos_brew
 from virtualenv.discovery import cached_py_info
 from virtualenv.discovery.py_info import PythonInfo, VersionInfo
 from virtualenv.discovery.py_spec import PythonSpec
@@ -22,6 +23,7 @@ from virtualenv.info import IS_PYPY, IS_WIN, fs_supports_symlink
 CURRENT = PythonInfo.current_system()
 
 
+@pytest.mark.graalpy
 def test_current_as_json():
     result = CURRENT._to_json()  # noqa: SLF001
     parsed = json.loads(result)
@@ -48,12 +50,12 @@ def test_bad_exe_py_info_no_raise(tmp_path, caplog, capsys, session_app_data):
     out, _ = capsys.readouterr()
     assert not out
     messages = [r.message for r in caplog.records if r.name != "filelock"]
-    assert len(messages) == 2
-    msg = messages[0]
-    assert "get interpreter info via cmd: " in msg
-    msg = messages[1]
-    assert str(exe) in msg
-    assert "code" in msg
+    assert len(messages) == 4  # two subprocess attempts (debug cmd + retry debug) + final info
+    assert "get interpreter info via cmd: " in messages[0]
+    assert "retrying" in messages[1]
+    assert "get interpreter info via cmd: " in messages[2]
+    assert str(exe) in messages[3]
+    assert "code" in messages[3]
 
 
 @pytest.mark.parametrize(
@@ -128,7 +130,7 @@ def test_py_info_cached_error(mocker, tmp_path, session_app_data):
         PythonInfo.from_exe(str(tmp_path), session_app_data)
     with pytest.raises(RuntimeError):
         PythonInfo.from_exe(str(tmp_path), session_app_data)
-    assert spy.call_count == 1
+    assert spy.call_count == 2  # initial attempt + one retry, second from_exe uses cache
 
 
 @pytest.mark.skipif(not fs_supports_symlink(), reason="symlink is not supported")
@@ -140,7 +142,7 @@ def test_py_info_cached_symlink_error(mocker, tmp_path, session_app_data):
     symlinked.symlink_to(tmp_path)
     with pytest.raises(RuntimeError):
         PythonInfo.from_exe(str(symlinked), session_app_data)
-    assert spy.call_count == 2
+    assert spy.call_count == 4  # 2 attempts per path (initial + retry)
 
 
 def test_py_info_cache_clear(mocker, session_app_data):
@@ -154,6 +156,41 @@ def test_py_info_cache_clear(mocker, session_app_data):
     assert spy.call_count >= 2 * count
 
 
+def test_py_info_cache_invalidation_on_py_info_change(mocker, session_app_data):
+    # 1. Get a PythonInfo object for the current executable, this will cache it.
+    PythonInfo.from_exe(sys.executable, session_app_data)
+
+    # 2. Spy on _run_subprocess
+    spy = mocker.spy(cached_py_info, "_run_subprocess")
+
+    # 3. Backup py_info.py
+    py_info_script = Path(cached_py_info.__file__).parent / "py_info.py"
+    original_content = py_info_script.read_text(encoding="utf-8")
+    original_stat = py_info_script.stat()
+
+    try:
+        # 4. Clear the in-memory cache
+        mocker.patch.dict(cached_py_info._CACHE, {}, clear=True)  # noqa: SLF001
+
+        # 5. Modify py_info.py to invalidate the cache
+        py_info_script.write_text(original_content + "\n# a comment", encoding="utf-8")
+
+        # 6. Get the PythonInfo object again
+        info = PythonInfo.from_exe(sys.executable, session_app_data)
+
+        # 7. Assert that _run_subprocess was called again
+        native_difference = 1 if info.system_executable == info.executable else 0
+        if is_macos_brew(info):
+            assert spy.call_count + native_difference in {2, 3}
+        else:
+            assert spy.call_count + native_difference == 2
+
+    finally:
+        # 8. Restore the original content and timestamp
+        py_info_script.write_text(original_content, encoding="utf-8")
+        os.utime(str(py_info_script), (original_stat.st_atime, original_stat.st_mtime))
+
+
 @pytest.mark.skipif(not fs_supports_symlink(), reason="symlink is not supported")
 @pytest.mark.xfail(
     # https://doc.pypy.org/en/latest/install.html?highlight=symlink#download-a-pre-built-pypy
@@ -338,10 +375,7 @@ def test_py_info_to_system_raises(session_app_data, mocker, caplog):
 
 
 def _stringify_schemes_dict(schemes_dict):
-    """
-    Since this file has from __future__ import unicode_literals, we manually cast all values of mocked install_schemes
-    to str() as the original schemes are not unicode on Python 2.
-    """
+    """Since this file has from __future__ import unicode_literals, we manually cast all values of mocked install_schemes to str() as the original schemes are not unicode on Python 2."""
     return {str(n): {str(k): str(v) for k, v in s.items()} for n, s in schemes_dict.items()}
 
 
@@ -400,7 +434,9 @@ def test_custom_venv_install_scheme_is_prefered(mocker):
     assert pyinfo.install_path("purelib").replace(os.sep, "/") == f"lib/python{pyver}/site-packages"
 
 
-@pytest.mark.skipif(not (os.name == "posix" and sys.version_info[:2] >= (3, 11)), reason="POSIX 3.11+ specific")
+@pytest.mark.skipif(
+    IS_PYPY or not (os.name == "posix" and sys.version_info[:2] >= (3, 11)), reason="POSIX 3.11+ specific"
+)
 def test_fallback_existent_system_executable(mocker):
     current = PythonInfo()
     # Posix may execute a "python" out of a venv but try to set the base_executable
@@ -491,3 +527,8 @@ def test_uses_posix_prefix_on_debian_3_10_without_venv(mocker):
     pyver = f"{pyinfo.version_info.major}.{pyinfo.version_info.minor}"
     assert pyinfo.install_path("scripts") == "bin"
     assert pyinfo.install_path("purelib").replace(os.sep, "/") == f"lib/python{pyver}/site-packages"
+
+
+def test_sysconfig_vars_include_shared_lib_keys() -> None:
+    for key in ("Py_ENABLE_SHARED", "INSTSONAME", "LIBDIR"):
+        assert key in CURRENT.sysconfig_vars
