@@ -1,9 +1,12 @@
+from __future__ import annotations
+
 import sys
 from copy import copy
 
 import pytest
 
 from virtualenv.discovery.py_spec import PythonSpec
+from virtualenv.util.specifier import SimpleSpecifierSet as SpecifierSet
 
 
 def test_bad_py_spec():
@@ -43,6 +46,16 @@ def test_spec_satisfies_arch():
     assert spec_2.satisfies(spec_1) is False
 
 
+def test_spec_satisfies_free_threaded():
+    spec_1 = PythonSpec.from_string_spec("python3.13t")
+    spec_2 = PythonSpec.from_string_spec("python3.13")
+
+    assert spec_1.satisfies(spec_1) is True
+    assert spec_1.free_threaded is True
+    assert spec_2.satisfies(spec_1) is False
+    assert spec_2.free_threaded is False
+
+
 @pytest.mark.parametrize(
     ("req", "spec"),
     [("py", "python"), ("jython", "jython"), ("CPython", "cpython")],
@@ -64,13 +77,22 @@ def test_spec_satisfies_implementation_nok():
 def _version_satisfies_pairs():
     target = set()
     version = tuple(str(i) for i in sys.version_info[0:3])
-    for i in range(len(version) + 1):
-        req = ".".join(version[0:i])
-        for j in range(i + 1):
-            sat = ".".join(version[0:j])
-            # can be satisfied in both directions
-            target.add((req, sat))
-            target.add((sat, req))
+    for threading in (False, True):
+        for i in range(len(version) + 1):
+            req = ".".join(version[0:i])
+            for j in range(i + 1):
+                sat = ".".join(version[0:j])
+                # can be satisfied in both directions
+                if sat:
+                    target.add((req, sat))
+                # else: no version => no free-threading info
+                target.add((sat, req))
+                if not threading or not sat or not req:
+                    # free-threading info requires a version
+                    continue
+                target.add((f"{req}t", f"{sat}t"))
+                target.add((f"{sat}t", f"{req}t"))
+
     return sorted(target)
 
 
@@ -111,3 +133,29 @@ def test_relative_spec(tmp_path, monkeypatch):
     a_relative_path = str((tmp_path / "a" / "b").relative_to(tmp_path))
     spec = PythonSpec.from_string_spec(a_relative_path)
     assert spec.path == a_relative_path
+
+
+@pytest.mark.parametrize(
+    ("text", "expected"),
+    [
+        (">=3.12", ">=3.12"),
+        ("python>=3.12", ">=3.12"),
+        ("cpython!=3.11.*", "!=3.11.*"),
+        ("<=3.13,>=3.12", "<=3.13,>=3.12"),
+    ],
+)
+def test_specifier_parsing(text, expected):
+    spec = PythonSpec.from_string_spec(text)
+    assert spec.version_specifier == SpecifierSet(expected)
+
+
+def test_specifier_with_implementation():
+    spec = PythonSpec.from_string_spec("cpython>=3.12")
+    assert spec.implementation == "cpython"
+    assert spec.version_specifier == SpecifierSet(">=3.12")
+
+
+def test_specifier_satisfies_with_partial_information():
+    spec = PythonSpec.from_string_spec(">=3.12")
+    candidate = PythonSpec.from_string_spec("python3.12")
+    assert candidate.satisfies(spec) is True
